@@ -1,6 +1,7 @@
 dclone.environment <- 
 function(x,  n.clones = 1, multiply = NULL, unchanged = NULL, 
-attrib = TRUE, ...) {
+attrib = TRUE, ...) 
+{
     dclone:::dclone.list(as.list(x),  n.clones, 
         multiply, unchanged, attrib, ...)
 }
